import "./index.less";
import { useNavigate } from "react-router-dom";
import { routerList } from "../../router";
import {
  Input,
  Modal,
  Form,
  Message,
  Button,
  Space,
  Radio,
  Tooltip,
} from "@arco-design/web-react";
import FormItem from "@arco-design/web-react/es/Form/form-item";
const InputSearch = Input.Search;
const RadioGroup = Radio.Group;
import { useEffect, useRef, useState } from "react";
import Row from "@arco-design/web-react/es/Table/summary/row";
import Col from "@arco-design/web-react/es/Grid/col";

type TLoginMethod = "usePass" | "useSms";

const DURATION = 120; // 验证码倒计时

function Nav() {
  const navigate = useNavigate();
  const [loginForm] = Form.useForm();
  const [visible, setVisible] = useState(false);
  const [confirmLoading, setConfirmLoading] = useState(false);
  const [loginMethod, setLoginMethod] = useState<TLoginMethod>("useSms");
  let [countdown, setCountdown] = useState(DURATION);
  const timer = useRef<any>();

  const onOk = () => {
    loginForm.validate().then((res) => {
      setConfirmLoading(true);
      setTimeout(() => {
        Message.success("Success !");
        setVisible(false);
        setConfirmLoading(false);
      }, 1500);
    });
  };

  const onClickSmsBtn = () => {
    setTimeout(() => {
      Message.success("验证码已发送");
      timer.current = setInterval(() => setCountdown(countdown--), 1000);
    }, 500);
  };

  useEffect(() => {
    if (countdown === 0) {
      clearInterval(timer.current);
      setCountdown(DURATION);
    }
  }, [countdown]);

  return (
    <header>
      <nav className="container">
        <div className="start">
          <svg
            fill="currentColor"
            className="icon"
            viewBox="0 0 1024 1024"
            version="1.1"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path d="M158.165333 499.498667A42.496 42.496 0 0 0 170.666667 469.333333V256a42.666667 42.666667 0 0 1 42.666666-42.666667 42.666667 42.666667 0 0 0 0-85.333333C142.762667 128 85.333333 185.429333 85.333333 256v195.669333l-30.165333 30.165334a42.666667 42.666667 0 0 0 0 60.330666l30.165333 30.165334V768c0 70.570667 57.429333 128 128 128a42.666667 42.666667 0 0 0 0-85.333333 42.666667 42.666667 0 0 1-42.666666-42.666667v-213.333333a42.496 42.496 0 0 0-12.501334-30.165334L145.664 512l12.501333-12.501333zM978.090667 495.658667a42.709333 42.709333 0 0 0-9.258667-13.824L938.666667 451.669333V256c0-70.570667-57.429333-128-128-128a42.666667 42.666667 0 1 0 0 85.333333 42.666667 42.666667 0 0 1 42.666666 42.666667v213.333333a42.581333 42.581333 0 0 0 12.501334 30.165334l12.501333 12.501333-12.501333 12.501333A42.496 42.496 0 0 0 853.333333 554.666667v213.333333a42.666667 42.666667 0 0 1-42.666666 42.666667 42.666667 42.666667 0 1 0 0 85.333333c70.570667 0 128-57.429333 128-128v-195.669333l30.165333-30.165334a42.709333 42.709333 0 0 0 9.258667-46.506666zM669.738667 225.450667a42.752 42.752 0 0 0-69.546667 14.762666l-255.829333 512a42.624 42.624 0 0 0 23.893333 55.424 42.922667 42.922667 0 0 0 55.552-23.765333l255.786667-512a42.538667 42.538667 0 0 0-9.813334-46.421333z"></path>
          </svg>
          <span>Backset</span>
        </div>
        <div className="middle">
          {routerList.map(
            (route) =>
              !route.invisible && (
                <span key={route.path} onClick={() => navigate(route.path)}>
                  {route.name}
                </span>
              )
          )}
          <InputSearch allowClear placeholder="搜索" style={{ width: 150 }} />
        </div>
        <div className="end">
          <span onClick={() => setVisible(true)}>登录</span>
          <Modal
            title={
              <RadioGroup
                type="button"
                defaultValue="useSms"
                onChange={(e) => setLoginMethod(e)}
              >
                <Radio value="useSms">验证码</Radio>
                <Radio value="usePass">密码</Radio>
              </RadioGroup>
            }
            style={{ width: "360px" }}
            visible={visible}
            onOk={onOk}
            okText="登录"
            cancelText="取消"
            closeIcon={false}
            confirmLoading={confirmLoading}
            onCancel={() => setVisible(false)}
          >
            <Form form={loginForm} layout="vertical">
              <FormItem field="用户名" rules={[{ required: true }]} label="">
                <Input size="large" placeholder="用户名/手机号" />
              </FormItem>
              {loginMethod === "useSms" ? (
                <FormItem required style={{ marginBottom: 0 }}>
                  <div className="sms-group">
                    <Input size="large" placeholder="验证码" type="text" />
                    <Button
                      size="large"
                      type="primary"
                      onClick={onClickSmsBtn}
                      disabled={countdown !== DURATION}
                    >
                      {countdown === DURATION ? "获取验证码" : `${countdown}s`}
                    </Button>
                  </div>
                </FormItem>
              ) : (
                <FormItem
                  field="密码"
                  rules={[{ required: true }]}
                  style={{ marginBottom: 0 }}
                  label=""
                >
                  <Input size="large" type="password" placeholder="密码" />
                </FormItem>
              )}
            </Form>
          </Modal>
        </div>
      </nav>
    </header>
  );
}

export default Nav;
